==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/sv.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Fel vid hämtning av åtkomst-token. Verifiera att din app-nyckel och hemlighet stämmer.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Kontroll av behörigheter misslyckades. Verifiera att ditt app-lösenord och hemlighet är korrekt.",
    "Please provide a valid app key and secret." : "Vänligen ange en giltig applikationsnyckel och hemlig fras.",
    "Step 1 failed. Exception: %s" : "Steg 1 flaerade. Undantag: %s",
    "Step 2 failed. Exception: %s" : "Steg 2 falerade. Undantag: %s",
    "External storages" : "Extern Lagring",
    "Dropbox App Configuration" : "Dropbox Konfiguration",
    "Google Drive App Configuration" : "Google Drive Konfiguration",
    "Personal" : "Privat",
    "System" : "System",
    "Grant access" : "Bevilja åtkomst",
    "Error configuring OAuth1" : "Misslyckades konfigurera OAuth1",
    "Error configuring OAuth2" : "Misslyckades konfigurera OAuth2",
    "Generate keys" : "Generera nycklar",
    "Error generating key pair" : "Fel vid generering av nyckelpar",
    "All users. Type to select user or group." : "Alla användare. Skriv för att välja användare eller grupp.",
    "(group)" : "(grupp)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilitet med Mac NFD kodning (slö)",
    "Admin defined" : "Admin definerad",
    "Saved" : "Sparad",
    "Saving..." : "Sparar...",
    "Save" : "Spara",
    "Empty response from the server" : "Tomt svar från servern",
    "Couldn't get the information from the remote server: {code} {type}" : "Kan ej läsa informationen från extern server: {code} {type} ",
    "Couldn't get the list of external mount points: {type}" : "Kunde inte hämta listan för externa monteringspunkter: {type}",
    "There was an error with message: " : "Det fanns ett fel med meddelande:",
    "External mount error" : "Fel vid extern montering",
    "external-storage" : "extern-lagring",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Några av de konfigurerade externa monteringspunkter är inte anslutna. Klicka på den röda rad(er) för mer information.",
    "Please enter the credentials for the {mount} mount" : "Vänligen ange uppgifterna för {mount} montering",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "Credentials saved" : "Sparade uppgifter",
    "Credentials saving failed" : "Misslyckades med att spara uppgifterna",
    "Credentials required" : "Uppgifter krävs",
    "Storage with ID \"%d\" not found" : "Lagringsutrymme med ID \"%d\" hittades inte",
    "Invalid backend or authentication mechanism class" : "Ogiltig backend eller autentiseringsmekanism-klass",
    "Invalid mount point" : "Ogiltig monteringspunkt",
    "Objectstore forbidden" : "Objekt förbjudet",
    "Invalid storage backend \"%s\"" : "Ogiltig lagrings backend \"%s\"",
    "Not permitted to use backend \"%s\"" : "Inte tillåtet att använda backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Inte tillåtet att använda autentiseringsmekanism \"%s\"",
    "Unsatisfied backend parameters" : "Otillfredsställda backend parametrar",
    "Unsatisfied authentication mechanism parameters" : "Otillfredsställda autentiseringsmekanism parametrar",
    "Insufficient data: %s" : "Otillräcklig data: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Lagringsutrymme med ID \"%d\" är inte redigerbart för användare",
    "Access key" : "Åtkomstnyckel",
    "Secret key" : "Hemlig nyckel",
    "Builtin" : "Inbyggt",
    "None" : "Ingen",
    "OAuth1" : "OAuth1",
    "App key" : "App-nyckel",
    "App secret" : "App-hemlighet",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient ID",
    "Client secret" : "Klienthemlighet",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Namn på arrendator",
    "Identity endpoint URL" : "Identitet endpoint URL",
    "Rackspace" : "Rackutrymme",
    "API key" : "API-nyckel",
    "Global credentials" : "Globala uppgifter",
    "Log-in credentials, save in database" : "Inloggningsuppgifter sparade i databasen",
    "Username and password" : "Användarnamn och lösenord",
    "Log-in credentials, save in session" : "Inloggninguppgifter, spara i sessionen",
    "User entered, store in database" : "Användare lades till, lagras i databasen",
    "RSA public key" : "RSA offentlig nyckel",
    "Public key" : "Offentlig nyckel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Värdnamn",
    "Port" : "Port",
    "Region" : "Län",
    "Enable SSL" : "Aktivera SSL",
    "Enable Path Style" : "Aktivera Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Extern mapp",
    "Secure https://" : "Säker https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Server",
    "Secure ftps://" : "Säker ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "Plats",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP-inloggning med hemlig nyckel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Dela",
    "Domain" : "Domän",
    "SMB / CIFS using OC login" : "SMB / CIFS använder OC inloggning",
    "Username as share" : "Användarnamn till utdelning",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Namn på tjänst",
    "Request timeout (seconds)" : "Sekunder för anslutningsförsök",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL-stöd i PHP är inte aktiverat eller har inte installerats. Montering av %s är inte möjlig. Be din systemadministratör om installation.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP-stöd i PHP är inte aktiverat eller har inte installerats. Montering av %s är inte möjlig. Be din systemadministratör om installation.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" är inte installerad. Montering av %s är inte möjlig. Be din systemadministratör om installation.",
    "No external storage configured" : "Ingen extern lagring konfigurerad",
    "You can add external storages in the personal settings" : "Du kan lägga till externa lagringar i de personliga inställningarna",
    "Name" : "Namn",
    "Storage type" : "Lagringstyp",
    "Scope" : "Scope",
    "Enable encryption" : "Aktivera kryptering",
    "Enable previews" : "Aktivera förhandsgranskningar",
    "Enable sharing" : "Aktivera delning",
    "Check for changes" : "Sök efter ändringar",
    "Never" : "Aldrig",
    "Once every direct access" : "En gång vid varje direktanslutning",
    "Folder name" : "Mappnamn",
    "External storage" : "Extern lagring",
    "Authentication" : "Autentisering",
    "Configuration" : "Konfiguration",
    "Available for" : "Tillgänglig för",
    "Add storage" : "Lägg till lagring",
    "Advanced settings" : "Avancerade inställningar",
    "Delete" : "Radera",
    "Allow users to mount external storage" : "Tillåt användare att montera extern lagring",
    "Allow users to mount the following external storage" : "Tillåt användare att montera följande extern lagring",
    "Storage with id \"%i\" not found" : "Lagring med id \"%i\" kan ej hittas",
    "Storage with id \"%i\" is not user editable" : "Lagring med id \"%i\" är inte redigerbar av användare"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/sv.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Extern Lagring",
    "Personal" : "Privat",
    "System" : "System",
    "Grant access" : "Bevilja åtkomst",
    "Error configuring OAuth1" : "Misslyckades konfigurera OAuth1",
    "Please provide a valid app key and secret." : "Vänligen ange en giltig applikationsnyckel och hemlig fras.",
    "Error configuring OAuth2" : "Misslyckades konfigurera OAuth2",
    "Generate keys" : "Generera nycklar",
    "Error generating key pair" : "Fel vid generering av nyckelpar",
    "All users. Type to select user or group." : "Alla användare. Skriv för att välja användare eller grupp.",
    "(group)" : "(grupp)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilitet med Mac NFD kodning (slö)",
    "Admin defined" : "Admin definerad",
    "Delete storage?" : "Ta bort lagring?",
    "Saved" : "Sparad",
    "Saving..." : "Sparar...",
    "Save" : "Spara",
    "Empty response from the server" : "Tomt svar från servern",
    "Couldn't access. Please log out and in again to activate this mount point" : "Kunde inte ansluta. Försök logga ut och in igen för att aktivera denna monteringspunkt",
    "Couldn't get the information from the remote server: {code} {type}" : "Kan ej läsa informationen från extern server: {code} {type} ",
    "Couldn't get the list of external mount points: {type}" : "Kunde inte hämta listan för externa monteringspunkter: {type}",
    "There was an error with message: " : "Det fanns ett fel med meddelande:",
    "External mount error" : "Fel vid extern montering",
    "external-storage" : "extern-lagring",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Kunde inte hämta lista med Windows nätverksmonteringspunkter: Tomt svar från servern",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Några av de konfigurerade externa monteringspunkter är inte anslutna. Klicka på den röda rad(er) för mer information.",
    "Please enter the credentials for the {mount} mount" : "Vänligen ange uppgifterna för {mount} montering",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "Credentials saved" : "Sparade uppgifter",
    "Credentials saving failed" : "Misslyckades med att spara uppgifterna",
    "Credentials required" : "Uppgifter krävs",
    "Storage with ID \"%d\" not found" : "Lagringsutrymme med ID \"%d\" hittades inte",
    "Invalid backend or authentication mechanism class" : "Ogiltig backend eller autentiseringsmekanism-klass",
    "Invalid mount point" : "Ogiltig monteringspunkt",
    "Objectstore forbidden" : "Objekt förbjudet",
    "Invalid storage backend \"%s\"" : "Ogiltig lagrings-backend \"%s\"",
    "Not permitted to use backend \"%s\"" : "Inte tillåtet att använda backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Inte tillåtet att använda autentiseringsmekanism \"%s\"",
    "Unsatisfied backend parameters" : "Otillfredsställda backend parametrar",
    "Unsatisfied authentication mechanism parameters" : "Otillfredsställda autentiseringsmekanism parametrar",
    "Insufficient data: %s" : "Otillräcklig data: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Lagringsutrymme med ID \"%d\" är inte redigerbart för användare",
    "Access key" : "Åtkomstnyckel",
    "Secret key" : "Hemlig nyckel",
    "Builtin" : "Inbyggt",
    "None" : "Ingen",
    "OAuth1" : "OAuth1",
    "App key" : "App-nyckel",
    "App secret" : "App-hemlighet",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient ID",
    "Client secret" : "Klienthemlighet",
    "Tenant name" : "Namn på arrendator",
    "Identity endpoint URL" : "Identitet endpoint URL",
    "Domain" : "Domän",
    "Rackspace" : "Rackutrymme",
    "API key" : "API-nyckel",
    "Global credentials" : "Globala uppgifter",
    "Log-in credentials, save in database" : "Inloggningsuppgifter sparade i databasen",
    "Username and password" : "Användarnamn och lösenord",
    "Log-in credentials, save in session" : "Inloggningsuppgifter, spara i sessionen",
    "User entered, store in database" : "Användare lades till, lagras i databasen",
    "RSA public key" : "RSA offentlig nyckel",
    "Public key" : "Offentlig nyckel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Värdnamn",
    "Port" : "Port",
    "Region" : "Län",
    "Enable SSL" : "Aktivera SSL",
    "Enable Path Style" : "Aktivera Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Extern undermapp",
    "Secure https://" : "Säker https://",
    "FTP" : "FTP",
    "Host" : "Server",
    "Secure ftps://" : "Säker ftps://",
    "Local" : "Lokal",
    "Location" : "Plats",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP-inloggning med hemlig nyckel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Dela",
    "SMB / CIFS using OC login" : "SMB / CIFS använder OC-inloggning",
    "Username as share" : "Användarnamn till utdelning",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Namn på tjänst",
    "Request timeout (seconds)" : "Sekunder för anslutningsförsök",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL-stöd i PHP är inte aktiverat eller har inte installerats. Montering av %s är inte möjlig. Be din systemadministratör om installation.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP-stöd i PHP är inte aktiverat eller har inte installerats. Montering av %s är inte möjlig. Be din systemadministratör om installation.",
    "Name" : "Namn",
    "Storage type" : "Lagringstyp",
    "Scope" : "Sammanhang",
    "Enable encryption" : "Aktivera kryptering",
    "Enable previews" : "Aktivera förhandsgranskningar",
    "Enable sharing" : "Aktivera delning",
    "Check for changes" : "Sök efter ändringar",
    "Never" : "Aldrig",
    "Once every direct access" : "En gång vid varje direktanslutning",
    "Folder name" : "Mappnamn",
    "External storage" : "Extern lagring",
    "Authentication" : "Autentisering",
    "Configuration" : "Konfiguration",
    "Available for" : "Tillgänglig för",
    "Add storage" : "Lägg till lagring",
    "Advanced settings" : "Avancerade inställningar",
    "Allow users to mount external storage" : "Tillåt användare att montera extern lagring",
    "OpenStack" : "OpenStack",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" är inte installerad. Montering av %s är inte möjlig. Be din systemadministratör om installation.",
    "No external storage configured" : "Ingen extern lagring konfigurerad",
    "You can add external storages in the personal settings" : "Du kan lägga till externa lagringar i de personliga inställningarna",
    "Delete" : "Radera",
    "Allow users to mount the following external storage" : "Tillåt användare att montera följande extern lagring",
    "Are you sure you want to delete this external storage" : "Är du säker att du vill ta bort denna externa lagringen"
},
"nplurals=2; plural=(n != 1);");
